@@ -44,6 +44,7 @@ __all__ = (
     "ListRepositoryAssociationsResponseTypeDef",
     "PaginatorConfigTypeDef",
     "CodeCommitRepositoryTypeDef",
+    "ThirdPartySourceRepositoryTypeDef",
     "RepositoryTypeDef",
 )
 
@@ -52,9 +53,10 @@ RepositoryAssociationTypeDef = TypedDict(
     {
         "AssociationId": str,
         "AssociationArn": str,
+        "ConnectionArn": str,
         "Name": str,
         "Owner": str,
-        "ProviderType": Literal["CodeCommit", "GitHub"],
+        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket"],
         "State": Literal["Associated", "Associating", "Failed", "Disassociating"],
         "StateReason": str,
         "LastUpdatedTimeStamp": datetime,
@@ -88,7 +90,7 @@ CodeReviewTypeDef = TypedDict(
         "CodeReviewArn": str,
         "RepositoryName": str,
         "Owner": str,
-        "ProviderType": Literal["CodeCommit", "GitHub"],
+        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket"],
         "State": Literal["Completed", "Pending", "Failed", "Deleting"],
         "StateReason": str,
         "CreatedTimeStamp": datetime,
@@ -147,7 +149,7 @@ CodeReviewSummaryTypeDef = TypedDict(
         "CodeReviewArn": str,
         "RepositoryName": str,
         "Owner": str,
-        "ProviderType": Literal["CodeCommit", "GitHub"],
+        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket"],
         "State": Literal["Completed", "Pending", "Failed", "Deleting"],
         "CreatedTimeStamp": datetime,
         "LastUpdatedTimeStamp": datetime,
@@ -201,11 +203,12 @@ RepositoryAssociationSummaryTypeDef = TypedDict(
     "RepositoryAssociationSummaryTypeDef",
     {
         "AssociationArn": str,
+        "ConnectionArn": str,
         "LastUpdatedTimeStamp": datetime,
         "AssociationId": str,
         "Name": str,
         "Owner": str,
-        "ProviderType": Literal["CodeCommit", "GitHub"],
+        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket"],
         "State": Literal["Associated", "Associating", "Failed", "Disassociating"],
     },
     total=False,
@@ -223,6 +226,12 @@ PaginatorConfigTypeDef = TypedDict(
 
 CodeCommitRepositoryTypeDef = TypedDict("CodeCommitRepositoryTypeDef", {"Name": str})
 
+ThirdPartySourceRepositoryTypeDef = TypedDict(
+    "ThirdPartySourceRepositoryTypeDef", {"Name": str, "ConnectionArn": str, "Owner": str}
+)
+
 RepositoryTypeDef = TypedDict(
-    "RepositoryTypeDef", {"CodeCommit": CodeCommitRepositoryTypeDef}, total=False
+    "RepositoryTypeDef",
+    {"CodeCommit": CodeCommitRepositoryTypeDef, "Bitbucket": ThirdPartySourceRepositoryTypeDef},
+    total=False,
 )
